.. image:: docs/source/_static/logo_ikiss.png
    :target: https://forge.ird.fr/diade/iKISS

|PythonVersions| |SnakemakeVersions| |Singularity|

**iKISS** (Kmer Inference Selection and Structure) is a snakemake reference-Free pipeline for inferring diversity, structuration, selection and genotype-phenotype association.

iKISS uses `KmersGWAS <https://github.com/voichek/kmersGWAS>`_,
`PCADAPT <https://cran.r-project.org/web/packages/pcadapt/readme/README.html>`_
and `LFMM <https://bcm-uga.github.io/lfmm/articles/lfmm>`_  to select genomics regions under selection.


Documentation
==============

Online documentation is on `ReadTheDocs <https://ikiss.readthedocs.io/en/latest/index.html>`_.


Authors
========

.. image:: docs/source/_static/ird_small.png
    :target: https://www.ird.fr

* `Julie Orjuela <mailto:julie.orjuela@ird.fr>`_ (UMR DIADE - IRD)

* Yves Vigouroux (UMR DIADE - IRD)


Licence
========

Licensed under  `GNU GENERAL PUBLIC LICENSE V3 <https://forge.ird.fr/diade/iKISS/-/blob/master/LICENCE?ref_type=heads>`_.

Intellectual property belongs to `IRD <https://www.ird.fr>`_ and authors.


.. |PythonVersions| image:: https://img.shields.io/badge/python-3.7%2B-blue
   :target: https://www.python.org/downloads
.. |SnakemakeVersions| image:: https://img.shields.io/badge/snakemake-≥5.10.0-brightgreen.svg?style=flat
   :target: https://snakemake.readthedocs.io
.. |Singularity| image:: https://img.shields.io/badge/singularity-≥3.3.0-7E4C74.svg
   :target: https://sylabs.io/docs/
.. |readthedocs| image:: https://pbs.twimg.com/media/E5oBxcRXoAEBSp1.png
   :target: https://culebront-pipeline.readthedocs.io/en/latest/
   :width: 400px


